from .ad_asset import (
    AdAppDeepLinkAsset as AdAppDeepLinkAsset,
    AdCallToActionAsset as AdCallToActionAsset,
    AdDemandGenCarouselCardAsset as AdDemandGenCarouselCardAsset,
    AdImageAsset as AdImageAsset,
    AdMediaBundleAsset as AdMediaBundleAsset,
    AdTextAsset as AdTextAsset,
    AdVideoAsset as AdVideoAsset,
    AdVideoAssetInfo as AdVideoAssetInfo,
    AdVideoAssetInventoryPreferences as AdVideoAssetInventoryPreferences,
    AdVideoAssetLinkFeatureControl as AdVideoAssetLinkFeatureControl,
)
from .ad_type_infos import (
    AppAdInfo as AppAdInfo,
    AppEngagementAdInfo as AppEngagementAdInfo,
    AppPreRegistrationAdInfo as AppPreRegistrationAdInfo,
    DemandGenCarouselAdInfo as DemandGenCarouselAdInfo,
    DemandGenMultiAssetAdInfo as DemandGenMultiAssetAdInfo,
    DemandGenProductAdInfo as DemandGenProductAdInfo,
    DemandGenVideoResponsiveAdInfo as DemandGenVideoResponsiveAdInfo,
    DisplayUploadAdInfo as DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo as ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo as ExpandedTextAdInfo,
    HotelAdInfo as HotelAdInfo,
    ImageAdInfo as ImageAdInfo,
    InFeedVideoAdInfo as InFeedVideoAdInfo,
    LegacyAppInstallAdInfo as LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo as LegacyResponsiveDisplayAdInfo,
    LocalAdInfo as LocalAdInfo,
    ResponsiveDisplayAdControlSpec as ResponsiveDisplayAdControlSpec,
    ResponsiveDisplayAdInfo as ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo as ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo as ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo as ShoppingProductAdInfo,
    ShoppingSmartAdInfo as ShoppingSmartAdInfo,
    SmartCampaignAdInfo as SmartCampaignAdInfo,
    TextAdInfo as TextAdInfo,
    TravelAdInfo as TravelAdInfo,
    VideoAdInfo as VideoAdInfo,
    VideoBumperInStreamAdInfo as VideoBumperInStreamAdInfo,
    VideoNonSkippableInStreamAdInfo as VideoNonSkippableInStreamAdInfo,
    VideoOutstreamAdInfo as VideoOutstreamAdInfo,
    VideoResponsiveAdInfo as VideoResponsiveAdInfo,
    VideoTrueViewInStreamAdInfo as VideoTrueViewInStreamAdInfo,
    YouTubeAudioAdInfo as YouTubeAudioAdInfo,
)
from .additional_application_info import (
    AdditionalApplicationInfo as AdditionalApplicationInfo,
)
from .asset_policy import (
    AdAssetPolicySummary as AdAssetPolicySummary,
    AssetDisapproved as AssetDisapproved,
    AssetLinkPrimaryStatusDetails as AssetLinkPrimaryStatusDetails,
)
from .asset_set_types import (
    BusinessProfileBusinessNameFilter as BusinessProfileBusinessNameFilter,
    BusinessProfileLocationGroup as BusinessProfileLocationGroup,
    BusinessProfileLocationSet as BusinessProfileLocationSet,
    ChainFilter as ChainFilter,
    ChainLocationGroup as ChainLocationGroup,
    ChainSet as ChainSet,
    DynamicBusinessProfileLocationGroupFilter as DynamicBusinessProfileLocationGroupFilter,
    LocationSet as LocationSet,
    MapsLocationInfo as MapsLocationInfo,
    MapsLocationSet as MapsLocationSet,
)
from .asset_types import (
    AppDeepLinkAsset as AppDeepLinkAsset,
    BookOnGoogleAsset as BookOnGoogleAsset,
    BusinessMessageAsset as BusinessMessageAsset,
    BusinessMessageCallToActionInfo as BusinessMessageCallToActionInfo,
    BusinessProfileLocation as BusinessProfileLocation,
    CallAsset as CallAsset,
    CalloutAsset as CalloutAsset,
    CallToActionAsset as CallToActionAsset,
    DemandGenCarouselCardAsset as DemandGenCarouselCardAsset,
    DynamicCustomAsset as DynamicCustomAsset,
    DynamicEducationAsset as DynamicEducationAsset,
    DynamicFlightsAsset as DynamicFlightsAsset,
    DynamicHotelsAndRentalsAsset as DynamicHotelsAndRentalsAsset,
    DynamicJobsAsset as DynamicJobsAsset,
    DynamicLocalAsset as DynamicLocalAsset,
    DynamicRealEstateAsset as DynamicRealEstateAsset,
    DynamicTravelAsset as DynamicTravelAsset,
    FacebookMessengerBusinessMessageInfo as FacebookMessengerBusinessMessageInfo,
    HotelCalloutAsset as HotelCalloutAsset,
    HotelPropertyAsset as HotelPropertyAsset,
    ImageAsset as ImageAsset,
    ImageDimension as ImageDimension,
    LeadFormAsset as LeadFormAsset,
    LeadFormCustomQuestionField as LeadFormCustomQuestionField,
    LeadFormDeliveryMethod as LeadFormDeliveryMethod,
    LeadFormField as LeadFormField,
    LeadFormSingleChoiceAnswers as LeadFormSingleChoiceAnswers,
    LocationAsset as LocationAsset,
    MediaBundleAsset as MediaBundleAsset,
    MobileAppAsset as MobileAppAsset,
    PageFeedAsset as PageFeedAsset,
    PriceAsset as PriceAsset,
    PriceOffering as PriceOffering,
    PromotionAsset as PromotionAsset,
    PromotionBarcodeInfo as PromotionBarcodeInfo,
    PromotionQrCodeInfo as PromotionQrCodeInfo,
    SitelinkAsset as SitelinkAsset,
    StructuredSnippetAsset as StructuredSnippetAsset,
    TextAsset as TextAsset,
    WebhookDelivery as WebhookDelivery,
    WhatsappBusinessMessageInfo as WhatsappBusinessMessageInfo,
    YoutubeVideoAsset as YoutubeVideoAsset,
    YouTubeVideoListAsset as YouTubeVideoListAsset,
    ZaloBusinessMessageInfo as ZaloBusinessMessageInfo,
)
from .asset_usage import AssetUsage as AssetUsage
from .audience_insights_attribute import (
    AudienceInsightsAttribute as AudienceInsightsAttribute,
    AudienceInsightsAttributeMetadata as AudienceInsightsAttributeMetadata,
    AudienceInsightsAttributeMetadataGroup as AudienceInsightsAttributeMetadataGroup,
    AudienceInsightsCategory as AudienceInsightsCategory,
    AudienceInsightsEntity as AudienceInsightsEntity,
    AudienceInsightsLineup as AudienceInsightsLineup,
    KnowledgeGraphAttributeMetadata as KnowledgeGraphAttributeMetadata,
    LineupAttributeMetadata as LineupAttributeMetadata,
    LocationAttributeMetadata as LocationAttributeMetadata,
    UserInterestAttributeMetadata as UserInterestAttributeMetadata,
    UserListAttributeMetadata as UserListAttributeMetadata,
    YouTubeChannelAttributeMetadata as YouTubeChannelAttributeMetadata,
    YouTubeVideoAttributeMetadata as YouTubeVideoAttributeMetadata,
)
from .audiences import (
    AgeDimension as AgeDimension,
    AgeSegment as AgeSegment,
    AudienceDimension as AudienceDimension,
    AudienceExclusionDimension as AudienceExclusionDimension,
    AudienceSegment as AudienceSegment,
    AudienceSegmentDimension as AudienceSegmentDimension,
    CustomAudienceSegment as CustomAudienceSegment,
    DetailedDemographicSegment as DetailedDemographicSegment,
    ExclusionSegment as ExclusionSegment,
    GenderDimension as GenderDimension,
    HouseholdIncomeDimension as HouseholdIncomeDimension,
    LifeEventSegment as LifeEventSegment,
    ParentalStatusDimension as ParentalStatusDimension,
    UserInterestSegment as UserInterestSegment,
    UserListSegment as UserListSegment,
)
from .bidding import (
    Commission as Commission,
    EnhancedCpc as EnhancedCpc,
    FixedCpm as FixedCpm,
    FixedCpmTargetFrequencyGoalInfo as FixedCpmTargetFrequencyGoalInfo,
    ManualCpa as ManualCpa,
    ManualCpc as ManualCpc,
    ManualCpm as ManualCpm,
    ManualCpv as ManualCpv,
    MaximizeConversions as MaximizeConversions,
    MaximizeConversionValue as MaximizeConversionValue,
    PercentCpc as PercentCpc,
    TargetCpa as TargetCpa,
    TargetCpc as TargetCpc,
    TargetCpm as TargetCpm,
    TargetCpmTargetFrequencyGoal as TargetCpmTargetFrequencyGoal,
    TargetCpv as TargetCpv,
    TargetImpressionShare as TargetImpressionShare,
    TargetRoas as TargetRoas,
    TargetSpend as TargetSpend,
)
from .campaign_goal_settings import CampaignGoalSettings as CampaignGoalSettings
from .click_location import ClickLocation as ClickLocation
from .consent import Consent as Consent
from .criteria import (
    ActivityCityInfo as ActivityCityInfo,
    ActivityCountryInfo as ActivityCountryInfo,
    ActivityIdInfo as ActivityIdInfo,
    ActivityRatingInfo as ActivityRatingInfo,
    ActivityStateInfo as ActivityStateInfo,
    AddressInfo as AddressInfo,
    AdScheduleInfo as AdScheduleInfo,
    AgeRangeInfo as AgeRangeInfo,
    AppPaymentModelInfo as AppPaymentModelInfo,
    AudienceInfo as AudienceInfo,
    BrandInfo as BrandInfo,
    BrandListInfo as BrandListInfo,
    CarrierInfo as CarrierInfo,
    CombinedAudienceInfo as CombinedAudienceInfo,
    ContentLabelInfo as ContentLabelInfo,
    CustomAffinityInfo as CustomAffinityInfo,
    CustomAudienceInfo as CustomAudienceInfo,
    CustomIntentInfo as CustomIntentInfo,
    DeviceInfo as DeviceInfo,
    ExtendedDemographicInfo as ExtendedDemographicInfo,
    GenderInfo as GenderInfo,
    GeoPointInfo as GeoPointInfo,
    HotelAdvanceBookingWindowInfo as HotelAdvanceBookingWindowInfo,
    HotelCheckInDateRangeInfo as HotelCheckInDateRangeInfo,
    HotelCheckInDayInfo as HotelCheckInDayInfo,
    HotelCityInfo as HotelCityInfo,
    HotelClassInfo as HotelClassInfo,
    HotelCountryRegionInfo as HotelCountryRegionInfo,
    HotelDateSelectionTypeInfo as HotelDateSelectionTypeInfo,
    HotelIdInfo as HotelIdInfo,
    HotelLengthOfStayInfo as HotelLengthOfStayInfo,
    HotelStateInfo as HotelStateInfo,
    IncomeRangeInfo as IncomeRangeInfo,
    InteractionTypeInfo as InteractionTypeInfo,
    IpBlockInfo as IpBlockInfo,
    KeywordInfo as KeywordInfo,
    KeywordThemeInfo as KeywordThemeInfo,
    LanguageInfo as LanguageInfo,
    LifeEventInfo as LifeEventInfo,
    ListingDimensionInfo as ListingDimensionInfo,
    ListingDimensionPath as ListingDimensionPath,
    ListingGroupInfo as ListingGroupInfo,
    ListingScopeInfo as ListingScopeInfo,
    LocalServiceIdInfo as LocalServiceIdInfo,
    LocationGroupInfo as LocationGroupInfo,
    LocationInfo as LocationInfo,
    MobileAppCategoryInfo as MobileAppCategoryInfo,
    MobileApplicationInfo as MobileApplicationInfo,
    MobileDeviceInfo as MobileDeviceInfo,
    NegativeKeywordListInfo as NegativeKeywordListInfo,
    OperatingSystemVersionInfo as OperatingSystemVersionInfo,
    ParentalStatusInfo as ParentalStatusInfo,
    PlacementInfo as PlacementInfo,
    PlacementListInfo as PlacementListInfo,
    ProductBrandInfo as ProductBrandInfo,
    ProductCategoryInfo as ProductCategoryInfo,
    ProductChannelExclusivityInfo as ProductChannelExclusivityInfo,
    ProductChannelInfo as ProductChannelInfo,
    ProductConditionInfo as ProductConditionInfo,
    ProductCustomAttributeInfo as ProductCustomAttributeInfo,
    ProductGroupingInfo as ProductGroupingInfo,
    ProductItemIdInfo as ProductItemIdInfo,
    ProductLabelsInfo as ProductLabelsInfo,
    ProductLegacyConditionInfo as ProductLegacyConditionInfo,
    ProductTypeFullInfo as ProductTypeFullInfo,
    ProductTypeInfo as ProductTypeInfo,
    ProximityInfo as ProximityInfo,
    SearchThemeInfo as SearchThemeInfo,
    TopicInfo as TopicInfo,
    UnknownListingDimensionInfo as UnknownListingDimensionInfo,
    UserInterestInfo as UserInterestInfo,
    UserListInfo as UserListInfo,
    VerticalAdsItemGroupRuleInfo as VerticalAdsItemGroupRuleInfo,
    VerticalAdsItemGroupRuleListInfo as VerticalAdsItemGroupRuleListInfo,
    VideoLineupInfo as VideoLineupInfo,
    WebpageConditionInfo as WebpageConditionInfo,
    WebpageInfo as WebpageInfo,
    WebpageListInfo as WebpageListInfo,
    WebpageSampleInfo as WebpageSampleInfo,
    YouTubeChannelInfo as YouTubeChannelInfo,
    YouTubeVideoInfo as YouTubeVideoInfo,
)
from .criterion_category_availability import (
    CriterionCategoryAvailability as CriterionCategoryAvailability,
    CriterionCategoryChannelAvailability as CriterionCategoryChannelAvailability,
    CriterionCategoryLocaleAvailability as CriterionCategoryLocaleAvailability,
)
from .custom_parameter import CustomParameter as CustomParameter
from .customizer_value import CustomizerValue as CustomizerValue
from .dates import (
    DateRange as DateRange,
    YearMonth as YearMonth,
    YearMonthRange as YearMonthRange,
)
from .extensions import (
    CallFeedItem as CallFeedItem,
    CalloutFeedItem as CalloutFeedItem,
    SitelinkFeedItem as SitelinkFeedItem,
)
from .feed_common import Money as Money
from .final_app_url import FinalAppUrl as FinalAppUrl
from .frequency_cap import (
    FrequencyCapEntry as FrequencyCapEntry,
    FrequencyCapKey as FrequencyCapKey,
)
from .goal_common import (
    CustomerLifecycleOptimizationValueSettings as CustomerLifecycleOptimizationValueSettings,
)
from .goal_setting import GoalSetting as GoalSetting
from .keyword_plan_common import (
    ConceptGroup as ConceptGroup,
    HistoricalMetricsOptions as HistoricalMetricsOptions,
    KeywordAnnotations as KeywordAnnotations,
    KeywordConcept as KeywordConcept,
    KeywordPlanAggregateMetricResults as KeywordPlanAggregateMetricResults,
    KeywordPlanAggregateMetrics as KeywordPlanAggregateMetrics,
    KeywordPlanDeviceSearches as KeywordPlanDeviceSearches,
    KeywordPlanHistoricalMetrics as KeywordPlanHistoricalMetrics,
    MonthlySearchVolume as MonthlySearchVolume,
)
from .lifecycle_goals import LifecycleGoalValueSettings as LifecycleGoalValueSettings
from .local_services import (
    LocalServicesDocumentReadOnly as LocalServicesDocumentReadOnly,
)
from .metric_goal import MetricGoal as MetricGoal
from .metrics import Metrics as Metrics, SearchVolumeRange as SearchVolumeRange
from .offline_user_data import (
    CustomerMatchUserListMetadata as CustomerMatchUserListMetadata,
    EventAttribute as EventAttribute,
    EventItemAttribute as EventItemAttribute,
    ItemAttribute as ItemAttribute,
    OfflineUserAddressInfo as OfflineUserAddressInfo,
    ShoppingLoyalty as ShoppingLoyalty,
    StoreAttribute as StoreAttribute,
    StoreSalesMetadata as StoreSalesMetadata,
    StoreSalesThirdPartyMetadata as StoreSalesThirdPartyMetadata,
    TransactionAttribute as TransactionAttribute,
    UserAttribute as UserAttribute,
    UserData as UserData,
    UserIdentifier as UserIdentifier,
)
from .policy import (
    PolicyTopicConstraint as PolicyTopicConstraint,
    PolicyTopicEntry as PolicyTopicEntry,
    PolicyTopicEvidence as PolicyTopicEvidence,
    PolicyValidationParameter as PolicyValidationParameter,
    PolicyViolationKey as PolicyViolationKey,
)
from .policy_summary import PolicySummary as PolicySummary
from .real_time_bidding_setting import RealTimeBiddingSetting as RealTimeBiddingSetting
from .segments import (
    AssetInteractionTarget as AssetInteractionTarget,
    BudgetCampaignAssociationStatus as BudgetCampaignAssociationStatus,
    Keyword as Keyword,
    Segments as Segments,
    SkAdNetworkSourceApp as SkAdNetworkSourceApp,
)
from .simulation import (
    BudgetSimulationPoint as BudgetSimulationPoint,
    BudgetSimulationPointList as BudgetSimulationPointList,
    CpcBidSimulationPoint as CpcBidSimulationPoint,
    CpcBidSimulationPointList as CpcBidSimulationPointList,
    CpvBidSimulationPoint as CpvBidSimulationPoint,
    CpvBidSimulationPointList as CpvBidSimulationPointList,
    PercentCpcBidSimulationPoint as PercentCpcBidSimulationPoint,
    PercentCpcBidSimulationPointList as PercentCpcBidSimulationPointList,
    TargetCpaSimulationPoint as TargetCpaSimulationPoint,
    TargetCpaSimulationPointList as TargetCpaSimulationPointList,
    TargetImpressionShareSimulationPoint as TargetImpressionShareSimulationPoint,
    TargetImpressionShareSimulationPointList as TargetImpressionShareSimulationPointList,
    TargetRoasSimulationPoint as TargetRoasSimulationPoint,
    TargetRoasSimulationPointList as TargetRoasSimulationPointList,
)
from .tag_snippet import TagSnippet as TagSnippet
from .targeting_setting import (
    TargetingSetting as TargetingSetting,
    TargetRestriction as TargetRestriction,
    TargetRestrictionOperation as TargetRestrictionOperation,
)
from .text_label import TextLabel as TextLabel
from .third_party_integration_partners import (
    CampaignThirdPartyBrandLiftIntegrationPartner as CampaignThirdPartyBrandLiftIntegrationPartner,
    CampaignThirdPartyBrandSafetyIntegrationPartner as CampaignThirdPartyBrandSafetyIntegrationPartner,
    CampaignThirdPartyIntegrationPartners as CampaignThirdPartyIntegrationPartners,
    CampaignThirdPartyReachIntegrationPartner as CampaignThirdPartyReachIntegrationPartner,
    CampaignThirdPartyViewabilityIntegrationPartner as CampaignThirdPartyViewabilityIntegrationPartner,
    CustomerThirdPartyBrandLiftIntegrationPartner as CustomerThirdPartyBrandLiftIntegrationPartner,
    CustomerThirdPartyBrandSafetyIntegrationPartner as CustomerThirdPartyBrandSafetyIntegrationPartner,
    CustomerThirdPartyIntegrationPartners as CustomerThirdPartyIntegrationPartners,
    CustomerThirdPartyReachIntegrationPartner as CustomerThirdPartyReachIntegrationPartner,
    CustomerThirdPartyViewabilityIntegrationPartner as CustomerThirdPartyViewabilityIntegrationPartner,
    ThirdPartyIntegrationPartnerData as ThirdPartyIntegrationPartnerData,
)
from .url_collection import UrlCollection as UrlCollection
from .user_lists import (
    BasicUserListInfo as BasicUserListInfo,
    CrmBasedUserListInfo as CrmBasedUserListInfo,
    FlexibleRuleOperandInfo as FlexibleRuleOperandInfo,
    FlexibleRuleUserListInfo as FlexibleRuleUserListInfo,
    LogicalUserListInfo as LogicalUserListInfo,
    LogicalUserListOperandInfo as LogicalUserListOperandInfo,
    LookalikeUserListInfo as LookalikeUserListInfo,
    RuleBasedUserListInfo as RuleBasedUserListInfo,
    SimilarUserListInfo as SimilarUserListInfo,
    UserListActionInfo as UserListActionInfo,
    UserListDateRuleItemInfo as UserListDateRuleItemInfo,
    UserListLogicalRuleInfo as UserListLogicalRuleInfo,
    UserListNumberRuleItemInfo as UserListNumberRuleItemInfo,
    UserListRuleInfo as UserListRuleInfo,
    UserListRuleItemGroupInfo as UserListRuleItemGroupInfo,
    UserListRuleItemInfo as UserListRuleItemInfo,
    UserListStringRuleItemInfo as UserListStringRuleItemInfo,
)
from .value import Value as Value

__all__ = [
    "AdAppDeepLinkAsset",
    "AdCallToActionAsset",
    "AdDemandGenCarouselCardAsset",
    "AdImageAsset",
    "AdMediaBundleAsset",
    "AdTextAsset",
    "AdVideoAsset",
    "AdVideoAssetInfo",
    "AdVideoAssetInventoryPreferences",
    "AdVideoAssetLinkFeatureControl",
    "AppAdInfo",
    "AppEngagementAdInfo",
    "AppPreRegistrationAdInfo",
    "DemandGenCarouselAdInfo",
    "DemandGenMultiAssetAdInfo",
    "DemandGenProductAdInfo",
    "DemandGenVideoResponsiveAdInfo",
    "DisplayUploadAdInfo",
    "ExpandedDynamicSearchAdInfo",
    "ExpandedTextAdInfo",
    "HotelAdInfo",
    "ImageAdInfo",
    "InFeedVideoAdInfo",
    "LegacyAppInstallAdInfo",
    "LegacyResponsiveDisplayAdInfo",
    "LocalAdInfo",
    "ResponsiveDisplayAdControlSpec",
    "ResponsiveDisplayAdInfo",
    "ResponsiveSearchAdInfo",
    "ShoppingComparisonListingAdInfo",
    "ShoppingProductAdInfo",
    "ShoppingSmartAdInfo",
    "SmartCampaignAdInfo",
    "TextAdInfo",
    "TravelAdInfo",
    "VideoAdInfo",
    "VideoBumperInStreamAdInfo",
    "VideoNonSkippableInStreamAdInfo",
    "VideoOutstreamAdInfo",
    "VideoResponsiveAdInfo",
    "VideoTrueViewInStreamAdInfo",
    "YouTubeAudioAdInfo",
    "AdditionalApplicationInfo",
    "AdAssetPolicySummary",
    "AssetDisapproved",
    "AssetLinkPrimaryStatusDetails",
    "BusinessProfileBusinessNameFilter",
    "BusinessProfileLocationGroup",
    "BusinessProfileLocationSet",
    "ChainFilter",
    "ChainLocationGroup",
    "ChainSet",
    "DynamicBusinessProfileLocationGroupFilter",
    "LocationSet",
    "MapsLocationInfo",
    "MapsLocationSet",
    "AppDeepLinkAsset",
    "BookOnGoogleAsset",
    "BusinessMessageAsset",
    "BusinessMessageCallToActionInfo",
    "BusinessProfileLocation",
    "CallAsset",
    "CalloutAsset",
    "CallToActionAsset",
    "DemandGenCarouselCardAsset",
    "DynamicCustomAsset",
    "DynamicEducationAsset",
    "DynamicFlightsAsset",
    "DynamicHotelsAndRentalsAsset",
    "DynamicJobsAsset",
    "DynamicLocalAsset",
    "DynamicRealEstateAsset",
    "DynamicTravelAsset",
    "FacebookMessengerBusinessMessageInfo",
    "HotelCalloutAsset",
    "HotelPropertyAsset",
    "ImageAsset",
    "ImageDimension",
    "LeadFormAsset",
    "LeadFormCustomQuestionField",
    "LeadFormDeliveryMethod",
    "LeadFormField",
    "LeadFormSingleChoiceAnswers",
    "LocationAsset",
    "MediaBundleAsset",
    "MobileAppAsset",
    "PageFeedAsset",
    "PriceAsset",
    "PriceOffering",
    "PromotionAsset",
    "PromotionBarcodeInfo",
    "PromotionQrCodeInfo",
    "SitelinkAsset",
    "StructuredSnippetAsset",
    "TextAsset",
    "WebhookDelivery",
    "WhatsappBusinessMessageInfo",
    "YoutubeVideoAsset",
    "YouTubeVideoListAsset",
    "ZaloBusinessMessageInfo",
    "AssetUsage",
    "AudienceInsightsAttribute",
    "AudienceInsightsAttributeMetadata",
    "AudienceInsightsAttributeMetadataGroup",
    "AudienceInsightsCategory",
    "AudienceInsightsEntity",
    "AudienceInsightsLineup",
    "KnowledgeGraphAttributeMetadata",
    "LineupAttributeMetadata",
    "LocationAttributeMetadata",
    "UserInterestAttributeMetadata",
    "UserListAttributeMetadata",
    "YouTubeChannelAttributeMetadata",
    "YouTubeVideoAttributeMetadata",
    "AgeDimension",
    "AgeSegment",
    "AudienceDimension",
    "AudienceExclusionDimension",
    "AudienceSegment",
    "AudienceSegmentDimension",
    "CustomAudienceSegment",
    "DetailedDemographicSegment",
    "ExclusionSegment",
    "GenderDimension",
    "HouseholdIncomeDimension",
    "LifeEventSegment",
    "ParentalStatusDimension",
    "UserInterestSegment",
    "UserListSegment",
    "Commission",
    "EnhancedCpc",
    "FixedCpm",
    "FixedCpmTargetFrequencyGoalInfo",
    "ManualCpa",
    "ManualCpc",
    "ManualCpm",
    "ManualCpv",
    "MaximizeConversions",
    "MaximizeConversionValue",
    "PercentCpc",
    "TargetCpa",
    "TargetCpc",
    "TargetCpm",
    "TargetCpmTargetFrequencyGoal",
    "TargetCpv",
    "TargetImpressionShare",
    "TargetRoas",
    "TargetSpend",
    "CampaignGoalSettings",
    "ClickLocation",
    "Consent",
    "ActivityCityInfo",
    "ActivityCountryInfo",
    "ActivityIdInfo",
    "ActivityRatingInfo",
    "ActivityStateInfo",
    "AddressInfo",
    "AdScheduleInfo",
    "AgeRangeInfo",
    "AppPaymentModelInfo",
    "AudienceInfo",
    "BrandInfo",
    "BrandListInfo",
    "CarrierInfo",
    "CombinedAudienceInfo",
    "ContentLabelInfo",
    "CustomAffinityInfo",
    "CustomAudienceInfo",
    "CustomIntentInfo",
    "DeviceInfo",
    "ExtendedDemographicInfo",
    "GenderInfo",
    "GeoPointInfo",
    "HotelAdvanceBookingWindowInfo",
    "HotelCheckInDateRangeInfo",
    "HotelCheckInDayInfo",
    "HotelCityInfo",
    "HotelClassInfo",
    "HotelCountryRegionInfo",
    "HotelDateSelectionTypeInfo",
    "HotelIdInfo",
    "HotelLengthOfStayInfo",
    "HotelStateInfo",
    "IncomeRangeInfo",
    "InteractionTypeInfo",
    "IpBlockInfo",
    "KeywordInfo",
    "KeywordThemeInfo",
    "LanguageInfo",
    "LifeEventInfo",
    "ListingDimensionInfo",
    "ListingDimensionPath",
    "ListingGroupInfo",
    "ListingScopeInfo",
    "LocalServiceIdInfo",
    "LocationGroupInfo",
    "LocationInfo",
    "MobileAppCategoryInfo",
    "MobileApplicationInfo",
    "MobileDeviceInfo",
    "NegativeKeywordListInfo",
    "OperatingSystemVersionInfo",
    "ParentalStatusInfo",
    "PlacementInfo",
    "PlacementListInfo",
    "ProductBrandInfo",
    "ProductCategoryInfo",
    "ProductChannelExclusivityInfo",
    "ProductChannelInfo",
    "ProductConditionInfo",
    "ProductCustomAttributeInfo",
    "ProductGroupingInfo",
    "ProductItemIdInfo",
    "ProductLabelsInfo",
    "ProductLegacyConditionInfo",
    "ProductTypeFullInfo",
    "ProductTypeInfo",
    "ProximityInfo",
    "SearchThemeInfo",
    "TopicInfo",
    "UnknownListingDimensionInfo",
    "UserInterestInfo",
    "UserListInfo",
    "VerticalAdsItemGroupRuleInfo",
    "VerticalAdsItemGroupRuleListInfo",
    "VideoLineupInfo",
    "WebpageConditionInfo",
    "WebpageInfo",
    "WebpageListInfo",
    "WebpageSampleInfo",
    "YouTubeChannelInfo",
    "YouTubeVideoInfo",
    "CriterionCategoryAvailability",
    "CriterionCategoryChannelAvailability",
    "CriterionCategoryLocaleAvailability",
    "CustomParameter",
    "CustomizerValue",
    "DateRange",
    "YearMonth",
    "YearMonthRange",
    "CallFeedItem",
    "CalloutFeedItem",
    "SitelinkFeedItem",
    "Money",
    "FinalAppUrl",
    "FrequencyCapEntry",
    "FrequencyCapKey",
    "CustomerLifecycleOptimizationValueSettings",
    "GoalSetting",
    "ConceptGroup",
    "HistoricalMetricsOptions",
    "KeywordAnnotations",
    "KeywordConcept",
    "KeywordPlanAggregateMetricResults",
    "KeywordPlanAggregateMetrics",
    "KeywordPlanDeviceSearches",
    "KeywordPlanHistoricalMetrics",
    "MonthlySearchVolume",
    "LifecycleGoalValueSettings",
    "LocalServicesDocumentReadOnly",
    "MetricGoal",
    "Metrics",
    "SearchVolumeRange",
    "CustomerMatchUserListMetadata",
    "EventAttribute",
    "EventItemAttribute",
    "ItemAttribute",
    "OfflineUserAddressInfo",
    "ShoppingLoyalty",
    "StoreAttribute",
    "StoreSalesMetadata",
    "StoreSalesThirdPartyMetadata",
    "TransactionAttribute",
    "UserAttribute",
    "UserData",
    "UserIdentifier",
    "PolicyTopicConstraint",
    "PolicyTopicEntry",
    "PolicyTopicEvidence",
    "PolicyValidationParameter",
    "PolicyViolationKey",
    "PolicySummary",
    "RealTimeBiddingSetting",
    "AssetInteractionTarget",
    "BudgetCampaignAssociationStatus",
    "Keyword",
    "Segments",
    "SkAdNetworkSourceApp",
    "BudgetSimulationPoint",
    "BudgetSimulationPointList",
    "CpcBidSimulationPoint",
    "CpcBidSimulationPointList",
    "CpvBidSimulationPoint",
    "CpvBidSimulationPointList",
    "PercentCpcBidSimulationPoint",
    "PercentCpcBidSimulationPointList",
    "TargetCpaSimulationPoint",
    "TargetCpaSimulationPointList",
    "TargetImpressionShareSimulationPoint",
    "TargetImpressionShareSimulationPointList",
    "TargetRoasSimulationPoint",
    "TargetRoasSimulationPointList",
    "TagSnippet",
    "TargetingSetting",
    "TargetRestriction",
    "TargetRestrictionOperation",
    "TextLabel",
    "CampaignThirdPartyBrandLiftIntegrationPartner",
    "CampaignThirdPartyBrandSafetyIntegrationPartner",
    "CampaignThirdPartyIntegrationPartners",
    "CampaignThirdPartyReachIntegrationPartner",
    "CampaignThirdPartyViewabilityIntegrationPartner",
    "CustomerThirdPartyBrandLiftIntegrationPartner",
    "CustomerThirdPartyBrandSafetyIntegrationPartner",
    "CustomerThirdPartyIntegrationPartners",
    "CustomerThirdPartyReachIntegrationPartner",
    "CustomerThirdPartyViewabilityIntegrationPartner",
    "ThirdPartyIntegrationPartnerData",
    "UrlCollection",
    "BasicUserListInfo",
    "CrmBasedUserListInfo",
    "FlexibleRuleOperandInfo",
    "FlexibleRuleUserListInfo",
    "LogicalUserListInfo",
    "LogicalUserListOperandInfo",
    "LookalikeUserListInfo",
    "RuleBasedUserListInfo",
    "SimilarUserListInfo",
    "UserListActionInfo",
    "UserListDateRuleItemInfo",
    "UserListLogicalRuleInfo",
    "UserListNumberRuleItemInfo",
    "UserListRuleInfo",
    "UserListRuleItemGroupInfo",
    "UserListRuleItemInfo",
    "UserListStringRuleItemInfo",
    "Value",
]



from .base import BillingSetupServiceTransport as BillingSetupServiceTransport
from .grpc import BillingSetupServiceGrpcTransport as BillingSetupServiceGrpcTransport
from .grpc_asyncio import (
    BillingSetupServiceGrpcAsyncIOTransport as BillingSetupServiceGrpcAsyncIOTransport,
)

__all__ = [
    "BillingSetupServiceTransport",
    "BillingSetupServiceGrpcTransport",
    "BillingSetupServiceGrpcAsyncIOTransport",
]



from .base import ConversionUploadServiceTransport as ConversionUploadServiceTransport
from .grpc import (
    ConversionUploadServiceGrpcTransport as ConversionUploadServiceGrpcTransport,
)
from .grpc_asyncio import (
    ConversionUploadServiceGrpcAsyncIOTransport as ConversionUploadServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ConversionUploadServiceTransport",
    "ConversionUploadServiceGrpcTransport",
    "ConversionUploadServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.common.types.audiences import (
    AudienceDimension,
    AudienceExclusionDimension,
)
from google.ads.googleads.v23.enums.types.audience_scope import AudienceScopeEnum
from google.ads.googleads.v23.enums.types.audience_status import AudienceStatusEnum

_M = TypeVar("_M")

class Audience(proto.Message):
    resource_name: str
    id: int
    status: AudienceStatusEnum.AudienceStatus
    name: str
    description: str
    dimensions: MutableSequence[AudienceDimension]
    exclusion_dimension: AudienceExclusionDimension
    scope: AudienceScopeEnum.AudienceScope
    asset_group: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        status: AudienceStatusEnum.AudienceStatus = ...,
        name: str = ...,
        description: str = ...,
        dimensions: MutableSequence[AudienceDimension] = ...,
        exclusion_dimension: AudienceExclusionDimension = ...,
        scope: AudienceScopeEnum.AudienceScope = ...,
        asset_group: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "status",
            "name",
            "description",
            "dimensions",
            "exclusion_dimension",
            "scope",
            "asset_group",
        ],
    ) -> bool: ...



import grpc

# Autogenerated imports
from google.ads.googleads.v20.errors import GoogleAdsFailure as GoogleAdsFailureV20
from google.ads.googleads.v21.errors import GoogleAdsFailure as GoogleAdsFailureV21
from google.ads.googleads.v22.errors import GoogleAdsFailure as GoogleAdsFailureV22
from google.ads.googleads.v23.errors import GoogleAdsFailure as GoogleAdsFailureV23

# End of autogenerated imports

GoogleAdsFailure = (
    # Autogenerated failure types
    GoogleAdsFailureV20
    | GoogleAdsFailureV21
    | GoogleAdsFailureV22
    | GoogleAdsFailureV23
    # End of autogenerated failure types
)

class GoogleAdsException(Exception):
    error: grpc.RpcError = ...
    call: grpc.Call = ...
    failure: GoogleAdsFailure = ...
    request_id: str = ...
    def __init__(
        self,
        error: grpc.RpcError,
        call: grpc.Call,
        failure: GoogleAdsFailure,
        request_id: str,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.type.money_pb2 import Money
from typing_extensions import Literal

_M = TypeVar("_M")

class ApplyIncentiveRequest(proto.Message):
    selected_incentive_id: int
    customer_id: str
    country_code: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        selected_incentive_id: int = ...,
        customer_id: str = ...,
        country_code: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["selected_incentive_id", "customer_id", "country_code"]
    ) -> bool: ...

class ApplyIncentiveResponse(proto.Message):
    coupon_code: str
    creation_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        coupon_code: str = ...,
        creation_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["coupon_code", "creation_time"]
    ) -> bool: ...

class CyoIncentives(proto.Message):
    low_offer: Incentive
    medium_offer: Incentive
    high_offer: Incentive
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        low_offer: Incentive = ...,
        medium_offer: Incentive = ...,
        high_offer: Incentive = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["low_offer", "medium_offer", "high_offer"]
    ) -> bool: ...

class FetchIncentiveRequest(proto.Message):
    class IncentiveType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        ACQUISITION = 2

    language_code: str
    country_code: str
    email: str
    type_: FetchIncentiveRequest.IncentiveType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        language_code: str = ...,
        country_code: str = ...,
        email: str = ...,
        type_: FetchIncentiveRequest.IncentiveType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["language_code", "country_code", "email", "type_"]
    ) -> bool: ...

class FetchIncentiveResponse(proto.Message):
    incentive_offer: IncentiveOffer
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        incentive_offer: IncentiveOffer = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["incentive_offer"]
    ) -> bool: ...

class Incentive(proto.Message):
    class Requirement(proto.Message):
        class Spend(proto.Message):
            award_amount: Money
            required_amount: Money
            def __init__(
                self: _M,
                mapping: _M | Mapping | google.protobuf.message.Message | None = None,
                *,
                ignore_unknown_fields: bool = False,
                award_amount: Money = ...,
                required_amount: Money = ...,
            ) -> None: ...
            def __contains__(  # type: ignore[override]
                self, key: Literal["award_amount", "required_amount"]
            ) -> bool: ...

        spend: Incentive.Requirement.Spend
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            spend: Incentive.Requirement.Spend = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["spend"]
        ) -> bool: ...

    incentive_id: int
    requirement: Incentive.Requirement
    incentive_terms_and_conditions_url: str
    type_: FetchIncentiveRequest.IncentiveType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        incentive_id: int = ...,
        requirement: Incentive.Requirement = ...,
        incentive_terms_and_conditions_url: str = ...,
        type_: FetchIncentiveRequest.IncentiveType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "incentive_id", "requirement", "incentive_terms_and_conditions_url", "type_"
        ],
    ) -> bool: ...

class IncentiveOffer(proto.Message):
    class OfferType(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        NO_INCENTIVE = 2
        CYO_INCENTIVE = 3

    type_: IncentiveOffer.OfferType
    consolidated_terms_and_conditions_url: str
    cyo_incentives: CyoIncentives
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        type_: IncentiveOffer.OfferType = ...,
        consolidated_terms_and_conditions_url: str = ...,
        cyo_incentives: CyoIncentives = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "type_", "consolidated_terms_and_conditions_url", "cyo_incentives"
        ],
    ) -> bool: ...



from .async_client import (
    CustomerLifecycleGoalServiceAsyncClient as CustomerLifecycleGoalServiceAsyncClient,
)
from .client import (
    CustomerLifecycleGoalServiceClient as CustomerLifecycleGoalServiceClient,
)

__all__ = [
    "CustomerLifecycleGoalServiceClient",
    "CustomerLifecycleGoalServiceAsyncClient",
]



from .async_client import (
    SharedCriterionServiceAsyncClient as SharedCriterionServiceAsyncClient,
)
from .client import SharedCriterionServiceClient as SharedCriterionServiceClient

__all__ = ["SharedCriterionServiceClient", "SharedCriterionServiceAsyncClient"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v20.common.types.criteria import AdScheduleInfo
from google.ads.googleads.v20.common.types.feed_common import Money
from google.ads.googleads.v20.enums.types.business_message_call_to_action_type import (
    BusinessMessageCallToActionTypeEnum,
)
from google.ads.googleads.v20.enums.types.business_message_provider import (
    BusinessMessageProviderEnum,
)
from google.ads.googleads.v20.enums.types.call_conversion_reporting_state import (
    CallConversionReportingStateEnum,
)
from google.ads.googleads.v20.enums.types.call_to_action_type import (
    CallToActionTypeEnum,
)
from google.ads.googleads.v20.enums.types.lead_form_call_to_action_type import (
    LeadFormCallToActionTypeEnum,
)
from google.ads.googleads.v20.enums.types.lead_form_desired_intent import (
    LeadFormDesiredIntentEnum,
)
from google.ads.googleads.v20.enums.types.lead_form_field_user_input_type import (
    LeadFormFieldUserInputTypeEnum,
)
from google.ads.googleads.v20.enums.types.lead_form_post_submit_call_to_action_type import (
    LeadFormPostSubmitCallToActionTypeEnum,
)
from google.ads.googleads.v20.enums.types.location_ownership_type import (
    LocationOwnershipTypeEnum,
)
from google.ads.googleads.v20.enums.types.mime_type import MimeTypeEnum
from google.ads.googleads.v20.enums.types.mobile_app_vendor import MobileAppVendorEnum
from google.ads.googleads.v20.enums.types.price_extension_price_qualifier import (
    PriceExtensionPriceQualifierEnum,
)
from google.ads.googleads.v20.enums.types.price_extension_price_unit import (
    PriceExtensionPriceUnitEnum,
)
from google.ads.googleads.v20.enums.types.price_extension_type import (
    PriceExtensionTypeEnum,
)
from google.ads.googleads.v20.enums.types.promotion_extension_discount_modifier import (
    PromotionExtensionDiscountModifierEnum,
)
from google.ads.googleads.v20.enums.types.promotion_extension_occasion import (
    PromotionExtensionOccasionEnum,
)

_M = TypeVar("_M")

class AppDeepLinkAsset(proto.Message):
    app_deep_link_uri: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        app_deep_link_uri: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["app_deep_link_uri"]
    ) -> bool: ...

class BookOnGoogleAsset(proto.Message):
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...

class BusinessMessageAsset(proto.Message):
    message_provider: BusinessMessageProviderEnum.BusinessMessageProvider
    starter_message: str
    call_to_action: BusinessMessageCallToActionInfo
    whatsapp_info: WhatsappBusinessMessageInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        message_provider: BusinessMessageProviderEnum.BusinessMessageProvider = ...,
        starter_message: str = ...,
        call_to_action: BusinessMessageCallToActionInfo = ...,
        whatsapp_info: WhatsappBusinessMessageInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "message_provider", "starter_message", "call_to_action", "whatsapp_info"
        ],
    ) -> bool: ...

class BusinessMessageCallToActionInfo(proto.Message):
    call_to_action_selection: (
        BusinessMessageCallToActionTypeEnum.BusinessMessageCallToActionType
    )
    call_to_action_description: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        call_to_action_selection: BusinessMessageCallToActionTypeEnum.BusinessMessageCallToActionType = ...,
        call_to_action_description: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["call_to_action_selection", "call_to_action_description"]
    ) -> bool: ...

class BusinessProfileLocation(proto.Message):
    labels: MutableSequence[str]
    store_code: str
    listing_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        labels: MutableSequence[str] = ...,
        store_code: str = ...,
        listing_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["labels", "store_code", "listing_id"]
    ) -> bool: ...

class CallAsset(proto.Message):
    country_code: str
    phone_number: str
    call_conversion_reporting_state: (
        CallConversionReportingStateEnum.CallConversionReportingState
    )
    call_conversion_action: str
    ad_schedule_targets: MutableSequence[AdScheduleInfo]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        country_code: str = ...,
        phone_number: str = ...,
        call_conversion_reporting_state: CallConversionReportingStateEnum.CallConversionReportingState = ...,
        call_conversion_action: str = ...,
        ad_schedule_targets: MutableSequence[AdScheduleInfo] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "country_code",
            "phone_number",
            "call_conversion_reporting_state",
            "call_conversion_action",
            "ad_schedule_targets",
        ],
    ) -> bool: ...

class CallToActionAsset(proto.Message):
    call_to_action: CallToActionTypeEnum.CallToActionType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        call_to_action: CallToActionTypeEnum.CallToActionType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["call_to_action"]
    ) -> bool: ...

class CalloutAsset(proto.Message):
    callout_text: str
    start_date: str
    end_date: str
    ad_schedule_targets: MutableSequence[AdScheduleInfo]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        callout_text: str = ...,
        start_date: str = ...,
        end_date: str = ...,
        ad_schedule_targets: MutableSequence[AdScheduleInfo] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["callout_text", "start_date", "end_date", "ad_schedule_targets"],
    ) -> bool: ...

class DemandGenCarouselCardAsset(proto.Message):
    marketing_image_asset: str
    square_marketing_image_asset: str
    portrait_marketing_image_asset: str
    headline: str
    call_to_action_text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        marketing_image_asset: str = ...,
        square_marketing_image_asset: str = ...,
        portrait_marketing_image_asset: str = ...,
        headline: str = ...,
        call_to_action_text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "marketing_image_asset",
            "square_marketing_image_asset",
            "portrait_marketing_image_asset",
            "headline",
            "call_to_action_text",
        ],
    ) -> bool: ...

class DynamicCustomAsset(proto.Message):
    id: str
    id2: str
    item_title: str
    item_subtitle: str
    item_description: str
    item_address: str
    item_category: str
    price: str
    sale_price: str
    formatted_price: str
    formatted_sale_price: str
    image_url: str
    contextual_keywords: MutableSequence[str]
    android_app_link: str
    ios_app_link: str
    ios_app_store_id: int
    similar_ids: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        id: str = ...,
        id2: str = ...,
        item_title: str = ...,
        item_subtitle: str = ...,
        item_description: str = ...,
        item_address: str = ...,
        item_category: str = ...,
        price: str = ...,
        sale_price: str = ...,
        formatted_price: str = ...,
        formatted_sale_price: str = ...,
        image_url: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        android_app_link: str = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
        similar_ids: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "id",
            "id2",
            "item_title",
            "item_subtitle",
            "item_description",
            "item_address",
            "item_category",
            "price",
            "sale_price",
            "formatted_price",
            "formatted_sale_price",
            "image_url",
            "contextual_keywords",
            "android_app_link",
            "ios_app_link",
            "ios_app_store_id",
            "similar_ids",
        ],
    ) -> bool: ...

class DynamicEducationAsset(proto.Message):
    program_id: str
    location_id: str
    program_name: str
    subject: str
    program_description: str
    school_name: str
    address: str
    contextual_keywords: MutableSequence[str]
    android_app_link: str
    similar_program_ids: MutableSequence[str]
    ios_app_link: str
    ios_app_store_id: int
    thumbnail_image_url: str
    image_url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        program_id: str = ...,
        location_id: str = ...,
        program_name: str = ...,
        subject: str = ...,
        program_description: str = ...,
        school_name: str = ...,
        address: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        android_app_link: str = ...,
        similar_program_ids: MutableSequence[str] = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
        thumbnail_image_url: str = ...,
        image_url: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "program_id",
            "location_id",
            "program_name",
            "subject",
            "program_description",
            "school_name",
            "address",
            "contextual_keywords",
            "android_app_link",
            "similar_program_ids",
            "ios_app_link",
            "ios_app_store_id",
            "thumbnail_image_url",
            "image_url",
        ],
    ) -> bool: ...

class DynamicFlightsAsset(proto.Message):
    destination_id: str
    origin_id: str
    flight_description: str
    image_url: str
    destination_name: str
    origin_name: str
    flight_price: str
    flight_sale_price: str
    formatted_price: str
    formatted_sale_price: str
    android_app_link: str
    ios_app_link: str
    ios_app_store_id: int
    similar_destination_ids: MutableSequence[str]
    custom_mapping: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        destination_id: str = ...,
        origin_id: str = ...,
        flight_description: str = ...,
        image_url: str = ...,
        destination_name: str = ...,
        origin_name: str = ...,
        flight_price: str = ...,
        flight_sale_price: str = ...,
        formatted_price: str = ...,
        formatted_sale_price: str = ...,
        android_app_link: str = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
        similar_destination_ids: MutableSequence[str] = ...,
        custom_mapping: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "destination_id",
            "origin_id",
            "flight_description",
            "image_url",
            "destination_name",
            "origin_name",
            "flight_price",
            "flight_sale_price",
            "formatted_price",
            "formatted_sale_price",
            "android_app_link",
            "ios_app_link",
            "ios_app_store_id",
            "similar_destination_ids",
            "custom_mapping",
        ],
    ) -> bool: ...

class DynamicHotelsAndRentalsAsset(proto.Message):
    property_id: str
    property_name: str
    image_url: str
    destination_name: str
    description: str
    price: str
    sale_price: str
    star_rating: int
    category: str
    contextual_keywords: MutableSequence[str]
    address: str
    android_app_link: str
    ios_app_link: str
    ios_app_store_id: int
    formatted_price: str
    formatted_sale_price: str
    similar_property_ids: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        property_id: str = ...,
        property_name: str = ...,
        image_url: str = ...,
        destination_name: str = ...,
        description: str = ...,
        price: str = ...,
        sale_price: str = ...,
        star_rating: int = ...,
        category: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        address: str = ...,
        android_app_link: str = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
        formatted_price: str = ...,
        formatted_sale_price: str = ...,
        similar_property_ids: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "property_id",
            "property_name",
            "image_url",
            "destination_name",
            "description",
            "price",
            "sale_price",
            "star_rating",
            "category",
            "contextual_keywords",
            "address",
            "android_app_link",
            "ios_app_link",
            "ios_app_store_id",
            "formatted_price",
            "formatted_sale_price",
            "similar_property_ids",
        ],
    ) -> bool: ...

class DynamicJobsAsset(proto.Message):
    job_id: str
    location_id: str
    job_title: str
    job_subtitle: str
    description: str
    image_url: str
    job_category: str
    contextual_keywords: MutableSequence[str]
    address: str
    salary: str
    android_app_link: str
    similar_job_ids: MutableSequence[str]
    ios_app_link: str
    ios_app_store_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        job_id: str = ...,
        location_id: str = ...,
        job_title: str = ...,
        job_subtitle: str = ...,
        description: str = ...,
        image_url: str = ...,
        job_category: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        address: str = ...,
        salary: str = ...,
        android_app_link: str = ...,
        similar_job_ids: MutableSequence[str] = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "job_id",
            "location_id",
            "job_title",
            "job_subtitle",
            "description",
            "image_url",
            "job_category",
            "contextual_keywords",
            "address",
            "salary",
            "android_app_link",
            "similar_job_ids",
            "ios_app_link",
            "ios_app_store_id",
        ],
    ) -> bool: ...

class DynamicLocalAsset(proto.Message):
    deal_id: str
    deal_name: str
    subtitle: str
    description: str
    price: str
    sale_price: str
    image_url: str
    address: str
    category: str
    contextual_keywords: MutableSequence[str]
    formatted_price: str
    formatted_sale_price: str
    android_app_link: str
    similar_deal_ids: MutableSequence[str]
    ios_app_link: str
    ios_app_store_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        deal_id: str = ...,
        deal_name: str = ...,
        subtitle: str = ...,
        description: str = ...,
        price: str = ...,
        sale_price: str = ...,
        image_url: str = ...,
        address: str = ...,
        category: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        formatted_price: str = ...,
        formatted_sale_price: str = ...,
        android_app_link: str = ...,
        similar_deal_ids: MutableSequence[str] = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "deal_id",
            "deal_name",
            "subtitle",
            "description",
            "price",
            "sale_price",
            "image_url",
            "address",
            "category",
            "contextual_keywords",
            "formatted_price",
            "formatted_sale_price",
            "android_app_link",
            "similar_deal_ids",
            "ios_app_link",
            "ios_app_store_id",
        ],
    ) -> bool: ...

class DynamicRealEstateAsset(proto.Message):
    listing_id: str
    listing_name: str
    city_name: str
    description: str
    address: str
    price: str
    image_url: str
    property_type: str
    listing_type: str
    contextual_keywords: MutableSequence[str]
    formatted_price: str
    android_app_link: str
    ios_app_link: str
    ios_app_store_id: int
    similar_listing_ids: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        listing_id: str = ...,
        listing_name: str = ...,
        city_name: str = ...,
        description: str = ...,
        address: str = ...,
        price: str = ...,
        image_url: str = ...,
        property_type: str = ...,
        listing_type: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        formatted_price: str = ...,
        android_app_link: str = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
        similar_listing_ids: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "listing_id",
            "listing_name",
            "city_name",
            "description",
            "address",
            "price",
            "image_url",
            "property_type",
            "listing_type",
            "contextual_keywords",
            "formatted_price",
            "android_app_link",
            "ios_app_link",
            "ios_app_store_id",
            "similar_listing_ids",
        ],
    ) -> bool: ...

class DynamicTravelAsset(proto.Message):
    destination_id: str
    origin_id: str
    title: str
    destination_name: str
    destination_address: str
    origin_name: str
    price: str
    sale_price: str
    formatted_price: str
    formatted_sale_price: str
    category: str
    contextual_keywords: MutableSequence[str]
    similar_destination_ids: MutableSequence[str]
    image_url: str
    android_app_link: str
    ios_app_link: str
    ios_app_store_id: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        destination_id: str = ...,
        origin_id: str = ...,
        title: str = ...,
        destination_name: str = ...,
        destination_address: str = ...,
        origin_name: str = ...,
        price: str = ...,
        sale_price: str = ...,
        formatted_price: str = ...,
        formatted_sale_price: str = ...,
        category: str = ...,
        contextual_keywords: MutableSequence[str] = ...,
        similar_destination_ids: MutableSequence[str] = ...,
        image_url: str = ...,
        android_app_link: str = ...,
        ios_app_link: str = ...,
        ios_app_store_id: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "destination_id",
            "origin_id",
            "title",
            "destination_name",
            "destination_address",
            "origin_name",
            "price",
            "sale_price",
            "formatted_price",
            "formatted_sale_price",
            "category",
            "contextual_keywords",
            "similar_destination_ids",
            "image_url",
            "android_app_link",
            "ios_app_link",
            "ios_app_store_id",
        ],
    ) -> bool: ...

class HotelCalloutAsset(proto.Message):
    text: str
    language_code: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        text: str = ...,
        language_code: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["text", "language_code"]
    ) -> bool: ...

class HotelPropertyAsset(proto.Message):
    place_id: str
    hotel_address: str
    hotel_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        place_id: str = ...,
        hotel_address: str = ...,
        hotel_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["place_id", "hotel_address", "hotel_name"]
    ) -> bool: ...

class ImageAsset(proto.Message):
    data: bytes
    file_size: int
    mime_type: MimeTypeEnum.MimeType
    full_size: ImageDimension
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        data: bytes = ...,
        file_size: int = ...,
        mime_type: MimeTypeEnum.MimeType = ...,
        full_size: ImageDimension = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["data", "file_size", "mime_type", "full_size"]
    ) -> bool: ...

class ImageDimension(proto.Message):
    height_pixels: int
    width_pixels: int
    url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        height_pixels: int = ...,
        width_pixels: int = ...,
        url: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["height_pixels", "width_pixels", "url"]
    ) -> bool: ...

class LeadFormAsset(proto.Message):
    business_name: str
    call_to_action_type: LeadFormCallToActionTypeEnum.LeadFormCallToActionType
    call_to_action_description: str
    headline: str
    description: str
    privacy_policy_url: str
    post_submit_headline: str
    post_submit_description: str
    fields: MutableSequence[LeadFormField]
    custom_question_fields: MutableSequence[LeadFormCustomQuestionField]
    delivery_methods: MutableSequence[LeadFormDeliveryMethod]
    post_submit_call_to_action_type: (
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType
    )
    background_image_asset: str
    desired_intent: LeadFormDesiredIntentEnum.LeadFormDesiredIntent
    custom_disclosure: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        business_name: str = ...,
        call_to_action_type: LeadFormCallToActionTypeEnum.LeadFormCallToActionType = ...,
        call_to_action_description: str = ...,
        headline: str = ...,
        description: str = ...,
        privacy_policy_url: str = ...,
        post_submit_headline: str = ...,
        post_submit_description: str = ...,
        fields: MutableSequence[LeadFormField] = ...,
        custom_question_fields: MutableSequence[LeadFormCustomQuestionField] = ...,
        delivery_methods: MutableSequence[LeadFormDeliveryMethod] = ...,
        post_submit_call_to_action_type: LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType = ...,
        background_image_asset: str = ...,
        desired_intent: LeadFormDesiredIntentEnum.LeadFormDesiredIntent = ...,
        custom_disclosure: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "business_name",
            "call_to_action_type",
            "call_to_action_description",
            "headline",
            "description",
            "privacy_policy_url",
            "post_submit_headline",
            "post_submit_description",
            "fields",
            "custom_question_fields",
            "delivery_methods",
            "post_submit_call_to_action_type",
            "background_image_asset",
            "desired_intent",
            "custom_disclosure",
        ],
    ) -> bool: ...

class LeadFormCustomQuestionField(proto.Message):
    custom_question_text: str
    single_choice_answers: LeadFormSingleChoiceAnswers
    has_location_answer: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        custom_question_text: str = ...,
        single_choice_answers: LeadFormSingleChoiceAnswers = ...,
        has_location_answer: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "custom_question_text", "single_choice_answers", "has_location_answer"
        ],
    ) -> bool: ...

class LeadFormDeliveryMethod(proto.Message):
    webhook: WebhookDelivery
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        webhook: WebhookDelivery = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["webhook"]
    ) -> bool: ...

class LeadFormField(proto.Message):
    input_type: LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType
    single_choice_answers: LeadFormSingleChoiceAnswers
    has_location_answer: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        input_type: LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType = ...,
        single_choice_answers: LeadFormSingleChoiceAnswers = ...,
        has_location_answer: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["input_type", "single_choice_answers", "has_location_answer"]
    ) -> bool: ...

class LeadFormSingleChoiceAnswers(proto.Message):
    answers: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        answers: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["answers"]
    ) -> bool: ...

class LocationAsset(proto.Message):
    place_id: str
    business_profile_locations: MutableSequence[BusinessProfileLocation]
    location_ownership_type: LocationOwnershipTypeEnum.LocationOwnershipType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        place_id: str = ...,
        business_profile_locations: MutableSequence[BusinessProfileLocation] = ...,
        location_ownership_type: LocationOwnershipTypeEnum.LocationOwnershipType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "place_id", "business_profile_locations", "location_ownership_type"
        ],
    ) -> bool: ...

class MediaBundleAsset(proto.Message):
    data: bytes
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        data: bytes = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["data"]
    ) -> bool: ...

class MobileAppAsset(proto.Message):
    app_id: str
    app_store: MobileAppVendorEnum.MobileAppVendor
    link_text: str
    start_date: str
    end_date: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        app_id: str = ...,
        app_store: MobileAppVendorEnum.MobileAppVendor = ...,
        link_text: str = ...,
        start_date: str = ...,
        end_date: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["app_id", "app_store", "link_text", "start_date", "end_date"]
    ) -> bool: ...

class PageFeedAsset(proto.Message):
    page_url: str
    labels: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        page_url: str = ...,
        labels: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["page_url", "labels"]
    ) -> bool: ...

class PriceAsset(proto.Message):
    type_: PriceExtensionTypeEnum.PriceExtensionType
    price_qualifier: PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier
    language_code: str
    price_offerings: MutableSequence[PriceOffering]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        type_: PriceExtensionTypeEnum.PriceExtensionType = ...,
        price_qualifier: PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier = ...,
        language_code: str = ...,
        price_offerings: MutableSequence[PriceOffering] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["type_", "price_qualifier", "language_code", "price_offerings"],
    ) -> bool: ...

class PriceOffering(proto.Message):
    header: str
    description: str
    price: Money
    unit: PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit
    final_url: str
    final_mobile_url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        header: str = ...,
        description: str = ...,
        price: Money = ...,
        unit: PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit = ...,
        final_url: str = ...,
        final_mobile_url: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "header", "description", "price", "unit", "final_url", "final_mobile_url"
        ],
    ) -> bool: ...

class PromotionAsset(proto.Message):
    promotion_target: str
    discount_modifier: (
        PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier
    )
    redemption_start_date: str
    redemption_end_date: str
    occasion: PromotionExtensionOccasionEnum.PromotionExtensionOccasion
    language_code: str
    start_date: str
    end_date: str
    ad_schedule_targets: MutableSequence[AdScheduleInfo]
    percent_off: int
    money_amount_off: Money
    promotion_code: str
    orders_over_amount: Money
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        promotion_target: str = ...,
        discount_modifier: PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier = ...,
        redemption_start_date: str = ...,
        redemption_end_date: str = ...,
        occasion: PromotionExtensionOccasionEnum.PromotionExtensionOccasion = ...,
        language_code: str = ...,
        start_date: str = ...,
        end_date: str = ...,
        ad_schedule_targets: MutableSequence[AdScheduleInfo] = ...,
        percent_off: int = ...,
        money_amount_off: Money = ...,
        promotion_code: str = ...,
        orders_over_amount: Money = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "promotion_target",
            "discount_modifier",
            "redemption_start_date",
            "redemption_end_date",
            "occasion",
            "language_code",
            "start_date",
            "end_date",
            "ad_schedule_targets",
            "percent_off",
            "money_amount_off",
            "promotion_code",
            "orders_over_amount",
        ],
    ) -> bool: ...

class SitelinkAsset(proto.Message):
    link_text: str
    description1: str
    description2: str
    start_date: str
    end_date: str
    ad_schedule_targets: MutableSequence[AdScheduleInfo]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        link_text: str = ...,
        description1: str = ...,
        description2: str = ...,
        start_date: str = ...,
        end_date: str = ...,
        ad_schedule_targets: MutableSequence[AdScheduleInfo] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "link_text",
            "description1",
            "description2",
            "start_date",
            "end_date",
            "ad_schedule_targets",
        ],
    ) -> bool: ...

class StructuredSnippetAsset(proto.Message):
    header: str
    values: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        header: str = ...,
        values: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["header", "values"]
    ) -> bool: ...

class TextAsset(proto.Message):
    text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["text"]
    ) -> bool: ...

class WebhookDelivery(proto.Message):
    advertiser_webhook_url: str
    google_secret: str
    payload_schema_version: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        advertiser_webhook_url: str = ...,
        google_secret: str = ...,
        payload_schema_version: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "advertiser_webhook_url", "google_secret", "payload_schema_version"
        ],
    ) -> bool: ...

class WhatsappBusinessMessageInfo(proto.Message):
    country_code: str
    phone_number: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        country_code: str = ...,
        phone_number: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["country_code", "phone_number"]
    ) -> bool: ...

class YoutubeVideoAsset(proto.Message):
    youtube_video_id: str
    youtube_video_title: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        youtube_video_id: str = ...,
        youtube_video_title: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["youtube_video_id", "youtube_video_title"]
    ) -> bool: ...



from .base import (
    ConversionAdjustmentUploadServiceTransport as ConversionAdjustmentUploadServiceTransport,
)
from .grpc import (
    ConversionAdjustmentUploadServiceGrpcTransport as ConversionAdjustmentUploadServiceGrpcTransport,
)
from .grpc_asyncio import (
    ConversionAdjustmentUploadServiceGrpcAsyncIOTransport as ConversionAdjustmentUploadServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ConversionAdjustmentUploadServiceTransport",
    "ConversionAdjustmentUploadServiceGrpcTransport",
    "ConversionAdjustmentUploadServiceGrpcAsyncIOTransport",
]



from typing import Callable, Sequence

import grpc
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v22.services.types import reach_plan_service

from .base import ReachPlanServiceTransport

__all__ = ["ReachPlanServiceGrpcTransport"]

class _LoggingClientInterceptor(grpc.UnaryUnaryClientInterceptor):
    def intercept_unary_unary(self, continuation, client_call_details, request): ...

class ReachPlanServiceGrpcTransport(ReachPlanServiceTransport):
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        channel: grpc.Channel | Callable[..., grpc.Channel] | None = None,
        api_mtls_endpoint: str | None = None,
        client_cert_source: Callable[[], tuple[bytes, bytes]] | None = None,
        ssl_channel_credentials: grpc.ChannelCredentials | None = None,
        client_cert_source_for_mtls: Callable[[], tuple[bytes, bytes]] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
        api_audience: str | None = None,
    ) -> None: ...
    @classmethod
    def create_channel(
        cls,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        **kwargs,
    ) -> grpc.Channel: ...
    @property
    def grpc_channel(self) -> grpc.Channel: ...
    @property
    def generate_conversion_rates(
        self,
    ) -> Callable[
        [reach_plan_service.GenerateConversionRatesRequest],
        reach_plan_service.GenerateConversionRatesResponse,
    ]: ...
    @property
    def list_plannable_locations(
        self,
    ) -> Callable[
        [reach_plan_service.ListPlannableLocationsRequest],
        reach_plan_service.ListPlannableLocationsResponse,
    ]: ...
    @property
    def list_plannable_products(
        self,
    ) -> Callable[
        [reach_plan_service.ListPlannableProductsRequest],
        reach_plan_service.ListPlannableProductsResponse,
    ]: ...
    @property
    def generate_reach_forecast(
        self,
    ) -> Callable[
        [reach_plan_service.GenerateReachForecastRequest],
        reach_plan_service.GenerateReachForecastResponse,
    ]: ...
    @property
    def list_plannable_user_lists(
        self,
    ) -> Callable[
        [reach_plan_service.ListPlannableUserListsRequest],
        reach_plan_service.ListPlannableUserListsResponse,
    ]: ...
    @property
    def list_plannable_user_interests(
        self,
    ) -> Callable[
        [reach_plan_service.ListPlannableUserInterestsRequest],
        reach_plan_service.ListPlannableUserInterestsResponse,
    ]: ...
    def close(self) -> None: ...
    @property
    def kind(self) -> str: ...



from typing import Any, AsyncIterator, Awaitable, Callable, Iterator, Sequence

from _typeshed import Incomplete
from google.rpc import status_pb2 as status_pb2

from google.ads.googleads.v22.services.types import campaign_draft_service

OptionalRetry: Incomplete
OptionalAsyncRetry: Incomplete

class ListCampaignDraftAsyncErrorsPager:
    def __init__(
        self,
        method: Callable[
            ..., campaign_draft_service.ListCampaignDraftAsyncErrorsResponse
        ],
        request: campaign_draft_service.ListCampaignDraftAsyncErrorsRequest,
        response: campaign_draft_service.ListCampaignDraftAsyncErrorsResponse,
        *,
        retry: OptionalRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(
        self,
    ) -> Iterator[campaign_draft_service.ListCampaignDraftAsyncErrorsResponse]: ...
    def __iter__(self) -> Iterator[status_pb2.Status]: ...

class ListCampaignDraftAsyncErrorsAsyncPager:
    def __init__(
        self,
        method: Callable[
            ..., Awaitable[campaign_draft_service.ListCampaignDraftAsyncErrorsResponse]
        ],
        request: campaign_draft_service.ListCampaignDraftAsyncErrorsRequest,
        response: campaign_draft_service.ListCampaignDraftAsyncErrorsResponse,
        *,
        retry: OptionalAsyncRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    async def pages(
        self,
    ) -> AsyncIterator[campaign_draft_service.ListCampaignDraftAsyncErrorsResponse]: ...
    def __aiter__(self) -> AsyncIterator[status_pb2.Status]: ...



from .base import GeoTargetConstantServiceTransport as GeoTargetConstantServiceTransport
from .grpc import (
    GeoTargetConstantServiceGrpcTransport as GeoTargetConstantServiceGrpcTransport,
)
from .grpc_asyncio import (
    GeoTargetConstantServiceGrpcAsyncIOTransport as GeoTargetConstantServiceGrpcAsyncIOTransport,
)

__all__ = [
    "GeoTargetConstantServiceTransport",
    "GeoTargetConstantServiceGrpcTransport",
    "GeoTargetConstantServiceGrpcAsyncIOTransport",
]
